id stringlengths 5 11 | text stringlengths 0 146k | title stringclasses 1
value |
|---|---|---|
doc_23531200 | <!DOCTYPE html>
<html>
<script src="https://ajax.googleapis.com/ajax/libs/angularjs/1.6.9/angular.min.js"></script>
<body>
<p>Change the value of the input field:</p>
<div ng-app="" ng-init="myCol='lightblue'">
<input style="background-color:{{myCol}}" ng-model="myCol">
</div>
<p>AngularJS resolves the expression ... | |
doc_23531201 | Possible Duplicate:
how to import from MS excel into MYSQL DB
I wish to import some data from excel to mysql database. my query is
LOAD DATA LOCAL INFILE 'd:/Book1.csv' INTO TABLE exp FIELDS TERMINATED BY ',' LINES TERMINATED BY '\n';
I receive an error File 'd:/Book1.csv' not found. Is there anything i want to do.
... | |
doc_23531202 | For example d(i,j) = 10, and d(j,i) = infinity or d(i,j) = 10 and d(j,i) = 20
Is it possible to create a new (undirected) graph that has all this information? I can add more nodes and edges if necessary.
By undirected I mean this: A graph where d(i,j) = d(j,i) and if d(i,j) exists then d(j,i) exists.
| |
doc_23531203 | When using the following line of code, the script calls upon the job and runs it, only if job_name is in the MAIN folder, then prints output or error to job_name.out/.err in the WORK folder.
system("$job_name > ./WORK/$job_name.out 2> ./WORK/$job_name.err");
If I move the jobs into SCRIPTS then I cannot seem to find ... | |
doc_23531204 | the final part looks something like this:
execution_path = os.getcwd()
detector = VideoObjectDetection()
detector.setModelTypeAsYOLOv3()
detector.setModelPath(os.path.join(execution_path , "yolo.h5"))
detector.loadModel()
print('Model loaded')
cap = cv2.VideoCapture(0)
video_path = detector.detectObjectsFromVideo(cam... | |
doc_23531205 | Great price, but it seems that it has a draw back.
It seems to need the bundle.crt in order to work correctly on must browser.
I'm not yet really sure what it is, from what I have understand it is an intermediate certificate from Certificate Authority. Correct me if I'm wrong
So in my software I have openssl
SSL_CTX_se... | |
doc_23531206 | @Target({ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
@Documented
public @interface Component {
String value() default "";
}
@Target({ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Component
public @interface Configuration {
String value() default "";
}
How can I konw Configurati... | |
doc_23531207 | http://imageshack.us/photo/my-images/850/y1xk.png/
This is the code:
int x = canvas.getWidth();
int y = 0;
int x_margin = 40;
int y_margin = 60;
for (int i=1; i < 51; i++) {
canvas.drawLine(x_margin, y + y_margin, x - x_margin, y + y_margin, mLinePaint);
if (i % 5 == 0) {
if ((i % 10 != 0) && (tracks... | |
doc_23531208 |
A: For me, JavaFX applications hosted in a browser always terminate automatically when the browser is closed.
You should implement Application.stop() to detect the application shutdown event.
Stage level methods setOnCloseRequest and setOnHiding are not the right methods for detecting an application level shutdown eve... | |
doc_23531209 | Let's define both select and unselect events, select one point by clicking on it, and then unselect it by selecting a different one. The thing is, that select event on new point fires before unselect event on the old point. I would prefer that event unselect of the old point would fire before select event on the new po... | |
doc_23531210 | This error occurs only when I run these 4 lines :-
image_batch, label_batch = next(iter(train_ds))
timeit(train_ds)
uncached_ds = prepare_for_training(labeled_ds, cache=False)
timeit(uncached_ds)
filecache_ds = prepare_for_training(labeled_ds, cache="./flowers.tfcache")
timeit(filecache_ds)
UnknownError: NewRandomAcc... | |
doc_23531211 | I can run if I right click on the Web project, click 'Run With' then 'Custom Configuration'. Works great.
However, the run item is disabled and I can't figure any way to enable it: http://prntscr.com/f7rsgh
A: Try loading the solution using Jetbrains Rider. https://www.jetbrains.com/rider
A: This sounds like it may b... | |
doc_23531212 | Here my tasks:
- name: ensure openssh-server is present
apt:
pkg: openssh-server
state: latest
install_recommends: no
force: yes
default_release: "{{ sshd_apt_backports_distribution }}"
notify: restart sshd
- name: ensure ed25519 host key is present
command: ssh-keygen -q -t ed25519 -N "" -f ... | |
doc_23531213 | int a = new int();
a = 111;
or
int a;
a = 111;
What does new int() exactly do?
A: The second, and if possible, simply:
int a = 111;
Value types do not need to use new()
Unlike classes, structs can be instantiated without using... | |
doc_23531214 | I recently came across a situation in a production application where my route composable was being called twice, causing a slight flicker in the UI. After digging into it for a few hours I discovered that the cause for the flicker was from using a hiltViewModel within the route for providing the ViewModel to my compose... | |
doc_23531215 | int a[N], b[N];
b[0] = a[0];
b[N] = a[N];
for (i=1; i<N-1; i++)
b[i]= a[i-1] + a[i] + a[i+1];
I thought about writing it this way, but I would like to find a better performing solution
__kernel void adjacentCopy(__global double *a, __global double *b, const unsigned int n) {
int gid = get_global_id(0);
... | |
doc_23531216 | I want to check if each list of a list of lists have, at least, one element inside. For example:
[[0], [0], [0, s(0), 0], [s(0)]] -> valid
[[0], [], [0, s(0), 0], [s(0)]] -> not valid (because of the [])
So I check it this way:
% Auxiliar Method 1
isList([]).
isList([_|Tail]) :-
isList(Tail).
% Auxiliar Method ... | |
doc_23531217 | On a working setup, I noticed that changes to the URL map take a long time to take effect.
For example, if I change for a working URL map a host-value from "abc.example.com" to "def.example.com", abc.example.com will remain available for at least a few minutes, while it takes a least some minutes, until def.example.com... | |
doc_23531218 | For this, I am using find_by, so I've been trying to do something like: User.find_by("replace(personal_id, '-', '.', ' ') = ?", 'replace(input, '-', '.', ' ')'). This is supposed to remove special characters from stored value and input value, and find the user that matches the search, but it is clearly not working and ... | |
doc_23531219 | position-sensitive-zooming
Sample code follows:
package test;
import java.awt.*;
import java.awt.event.*;
import java.awt.geom.*;
import javax.swing.*;
public class FPanel extends javax.swing.JPanel {
private Dimension preferredSize = new Dimension(400, 400);
private Rectangle2D[] rects = new Rectangle2D[50];
p... | |
doc_23531220 | This is what I have so far.
I want to sum the salary of managers, clerks, and analysts separately.
import pandas as pd
a = ['manager','sales','clerk','manager','analayst','sales','manager','analayst' ,'sales','clerk','clerk','analayst']
b = [45000,78000,12000,45000,96000,78000,56000,95000,84000,75000,95000,
26000]
... | |
doc_23531221 | for example:
let address1 = "Akshardham Temple, Vidyut Nagar, Vaishali Nagar, Chitrakoot, Jaipur, Rajasthan"
let address2 = "Statue of Unity, Statue of Unity Road, Kevadia, Gujarat"
// and some might be just this
let address3 = "New Delhi, Delhi"
what I want is however long string is I want to extract last two enti... | |
doc_23531222 | Error message: https://s4.postimg.org/if3ip9zfh/screenshot000213.jpg
A: It'll probably be easier to create a class via a script with DDL.
We do it like this:
CREATE OR REPLACE AND COMPILE JAVA SOURCE NAMED "IP6Address" AS
import java.math.BigInteger;
public class IP6Address
{
... -- whatever
}
/
We do that for pa... | |
doc_23531223 | H <- tcrossprod(tcrossprod(X, solve(crossprod(X))), X)
with X being a relatively large matrix (i.e 1e5*100), and this line has to run thousands of times. I understand the most limiting part is the inverse computation, but the crossproducts may be time-consuming too. Is there any faster alternative to perform these matr... | |
doc_23531224 | <html>
<body>
<script>create_a_div()</script>
</body>
</html>
The desired output is:
<html>
<body>
<div></div>
</body>
</html>
Is there any argument I could use in the function render to do this?
I would let that JavaScript code to be executed on Client side,
but I am not allowed to save it for security reasons.
A: ... | |
doc_23531225 | while($row=mysql_fetch_assoc($count_query_result))
$output[]=$row;
while($row=mysql_fetch_assoc($average_query_result))
$output2[]=$row;
while($row=mysql_fetch_assoc($items_query_result))
$output3[]=$row;
print(json_encode(array($output,$output2,$output3)));
mysql_close();
My question:
How do I take a sin... | |
doc_23531226 | The essence of the problem is that in Eclipse application runs, while in terminal (ubuntu) using the following line of code (where the Catalog "m /" indicates the location of the modules * .class):
java -jar ModularApp.jar m/
I get the following message:
10:07:24,085 DEBUG main CModuleLoader:findClass:39 - Run of the... | |
doc_23531227 | In jmeter-meter a Userdefined Variable is defined (e.g. authkey=1234567)
in csv-file is the soap-request:
<soap:Envelope xmlns:soap="http://www.w3.org/2003/05/soap-envelope">
<soap:Body>
<Request AuthKey="${Authkey}}">
<Element1>...</Element1>
</Request>
</soap:Body>
</soap:Envelope>... | |
doc_23531228 | In the below image, calAge is not returning a value.
A: What may be confusing you is that the code of that function, Tschool.Accepted is obviously incomplete; a value is assigned to the result value of the function if the if statement is true, but not otherwise. That's actually a programming error, because it means ... | |
doc_23531229 | This site has provided an excellent solution but not to one with strata (https://stat.ethz.ch/pipermail/r-help/2014-October/422348.html). How can i append (or stack) each strata with an extra column which contains the strata type.
solution in the link offered is not applicable to strata groupings
library(survival)
data... | |
doc_23531230 | Lets say person A enters the process A and completed the process and same person enters again and be the part of the process(in progress).
What I need is I need to get the unique total enrolled people count, I can get that using the below,
unique_count = ProcessPerson.where(status: %[completed inprogress]).select(:per... | |
doc_23531231 | egen afd_lr2 = mean(afd_lire2w) if ost == 0
Now I would like to replace the values with the mean of another variable if ost == 1:
replace afd_lr2 = mean(afd_lireo) if ost ==1
This is not possible, as the mean function cannot be used with the replace command.
How can I achieve my goal?
A: The following works for me:... | |
doc_23531232 |
*
*if 'head' is blank then remove the blank space.
*if the next letter of 'head' is blank , remove both the letter and the tail.
*if the 'head' and 'tail' are letters, I want the 'head'.
*if the 'head' is blank give me the next letter because that's one of acronym.
But when comes to a letter like "apple apple", i... | |
doc_23531233 | From a html form data is passed to a php code.It gives a error.
A: This is the standard way to use.
$firstname=$_GET['firstname'];
$lastname=$_GET['lastname'];
$email=$_GET['email'];
$sql = "INSERT INTO MyGuests (firstname, lastname, email)
VALUES ('".$firstname."','".$lastname."','".$email."')";
$stmt = $conn->prep... | |
doc_23531234 | Error:Failed to find target with hash string 'android-25' in: /Users/myuser/Library/Android/sdk
<a href="install.android.platform">Install missing platform(s) and sync project</a>
Where is the file where I have to set the sdk version, min or max ? Not the folder of sdk
the project come from an Ionic 3 project.
I've c... | |
doc_23531235 |
But when the screen size gets smaller, the text and image intercept. I'm looking to make it so the text conform to the boarders of the image. This is what's happening now:
Lastly, this is my CSS
.image {
width: 500px;
margin-left: auto;
display: block;
padding-top: 10%;
padding-right: 10%;
}
.text {
... | |
doc_23531236 | Problem:
When loading a page, content inside of a JQueryUI tabs fails. Looking at Chrome Developer Tools, the AJAX requests are returning 500 Internal Server Errors.
Typically, I'd look at the server's httpd error log (this is a CentOS system), but nothing shows as anything warning or higher. I changed the error log... | |
doc_23531237 | {
"ID_54321":{
"Name":"John Doe",
"Email":"jdoe@gmail123.com",
"Q1":"3"
}
}
I am able to retrieve the item.
for key in data:
for item in data[key]:
print item
Result
Name
Email
Q1
The issue is that I cannot retrieve the value for the item I am trying to retrieve.
for key in data:
... | |
doc_23531238 |
So I wanted to define the primary and foreign keys for each table.
Based on this answer, I saw that:
*
*"city" table has 1 PK (ID) and 1 FK (countrycode)
*"countrylanguage" table has 2 PK (Language and countrycode) and 1 FK
(countrycode)
*"country" table has 1 PK (Code)
So I tried to make some magic on a "pre-he... | |
doc_23531239 | Thank's
A: Try this code in VB.NET:
Protected Sub btnExport(ByVal sender As Object, ByVal e As System.EventArgs)
Dim TheFile As FileInfo = New FileInfo(MapPath(".") & "\" & "filename.xls")
' Connection String to Excel Workbook 2010 (xlsx)
' Dim excelConnectionString As String = "Provider=Microsoft.ACE.OLE... | |
doc_23531240 | end_time_string = data['endTime'] # Get the end time in a string in weird format
date_format = "%Y%m%dT%H%M%S.%fZ" # Specify the date format for the datetime parser
end_time = datetime.strptime(end_time_string, date_format) # turn the date time string into datetime object
current_time = datetime.utcnow() ... | |
doc_23531241 | What I am trying to do is display large images in the fancybox iframe of about width 900 and height 500. Of course right now images render huge and don't fit into that iframe.
I am having a hard time capturing the right class or a way to navigate to the image to resize it. What I tried is using beforeShow function and ... | |
doc_23531242 | My current code:
jt stands for journal title, pulled out properly from the file. GBIDs are added to the count as encountered.
... up to this point, the first search is performed, each "pmid" you can think of
as a single file, so each "fetch" goes through all the files one at a time...
pmid_list.each do |pmid|
... | |
doc_23531243 | My code:
setInterval(function() {
y.on('deviceconnected', function(device) {
console.log("Power off the device");
var state = false;
y.setPower(device, state, 300);
});
}, 3000);
That function powers off my room bulb and it works fine out of the setInterval.
Unfortunately, inside the setInterval it doesn... | |
doc_23531244 | Can you please me to get away from this Terminal screen
import Tkinter,ttk
import tkMessageBox
from Tkinter import *
import io,sys,os,subprocess
from tkFileDialog import askopenfilename
def askforvideo():
global process
name= askopenfilename(title=[("videopen")],filetypes=[("Video Files","*.h264")])
if na... | |
doc_23531245 | ||
doc_23531246 | Count ID size
0 25 0001 1
1 4 0001 2
2 9 0001 3
3 13 0001 4
4 19 0001 5
...
8 11 0003 10
9 10 0003 12
10 7 00... | |
doc_23531247 | I have reviewed several tutorials on how to create a maven project and the file structure in the tutorials is not what I am getting. Why am I missing several files?
note:
This is what tutorials show
This is what I get.
A: Both are same . Only view is different . You can change it by going to eclipse->window->show vie... | |
doc_23531248 |
You can see in the in the image that there are space on the left and right side. Please tell me how can I do that.
A: If you want this permanent for all cells, you can use.
self.tableView.contentInset = UIEdgeInsets(top: , left: , bottom: , right)
in your viewDidLoad() method
just change left and right as you like... | |
doc_23531249 | <div id="testA">
<ul>
<li>...</li>
</ul>
</div>
CSS:
div {
width: 12em;
background: #c6c6c6;
padding: 0.5em;
float: left;
margin-right: 1em;
}
ul {
margin: 0;
}
#testA ul {
border-radius: 6px;
background: #f6f6f6;
height: 6em;
overflow: auto;
}
A: The issue is actually caused by the bor... | |
doc_23531250 | The rules are
For a set of given values in control1; control2 is not enabled.
For a set of other values in control1; control2 is enabled.
I am trying to implement this behaviour:
With focus on control1, when the user is pressing tab we evaluate if control2 must be enabled or disabled, if control2 is enabled it gets the... | |
doc_23531251 | Kindly assist me on this.
A: You need to have at least basic knowledge on using adobe Photoshop.
a. You need to know how to deal with layers so you can extract the website carefully.
b. Use slicing tool. after you carefully slice each part. then you can now press and hold Ctrl+Shift+Alt+s (all at the same time) then ... | |
doc_23531252 | I'm getting the error even though the connection is fine.
"TypeError: _get_column_info() got an unexpected keyword argument 'generated'"
I tried with another databse of a different server it works fine...
But not sure whats the issue with this server tables.
Can you please help me out with a solution.
Table=sa.Table("T... | |
doc_23531253 | Example: I sometimes want to tell all other nodes to invalidate cache pages or notify them that something happened.
*
*Request-reply won't work because I don't want the requester to block waiting for an empty response. I want to allow multiple signals to build up at the server.
*Publish-subscribe feels wrong becaus... | |
doc_23531254 | Here is the image: http://imageshack.us/photo/my-images/841/7a83.png/.
But i am stuck with trying to figure out the matrix calculation. For example if the anchor rotates 45degrees, so its facing the x-axis, how can i make the rod still move backwards and forwards?
A: Just as scooby37 noticed, combination example provi... | |
doc_23531255 | By reading this article that expline what are Expression trees and what they are used for I have some question thats the article those not answer me clearly.
A. What is the difference between Data Structure and 'compiled piece of code'.
* I know that data structure is Array,List,.. But this is not the answer I am loo... | |
doc_23531256 | I am wondering if there is a way to pick up the domain name in the nuxt.config.js file?
| |
doc_23531257 | See first example home,Scripts,Snippet. if Script Parent is 1 it should under home tr,if Snippet parent id is 6 it is under the Script menu
<table id="sort-table">
<tbody>
<tr>
<th>Id</th>
<th>Parent</th>
<th>Title</th>
</tr>
<tr>
<td>1</td>
... | |
doc_23531258 | I am using kerassugeon for this and performing channel pruning.
Here are the relevant imports :
from kerassurgeon import identify
from kerassurgeon.operations import delete_channels, delete_layer
Here is the code of the same :
#load pre trained Xception model
model=tf.keras.applications.xception.Xception(weights='imag... | |
doc_23531259 | As far as I understand it is impossible to update the filter rules in real time. So I try to stop the stream and then start it again.
class MyStream(tweepy.StreamingClient):
def disconnect(self):
self.running=False
print('stop stream)
stream = MyStream(b... | |
doc_23531260 | Then I should write name either of file or dir and its status to db. Finally, I have to write to a new file, BUT if an item is a directory I have to find all files from this directory and write names of these files instead of the directory name.
I see this as two step job when the first step is to read from the file an... | |
doc_23531261 | auto I=V.array()>0;
For now, I always use auto, but I would prefer considering the right type before compilation. I have tried VectorXd, VectorXi, but it does not work. Any ideas?
| |
doc_23531262 | I don't know how GitHub works but I do have an account (with nothing on there) and want to start using it sometime. I am assuming this is not the way it is meant to show up. Can someone please tell me why this is happening and how to fix it. (btw I am not logged in to GitHub on my computer in any way if that is how it ... | |
doc_23531263 | <p class="one">Number One</p>
<script>
$( "p.one" ).click(function() {
$( this ).replaceWith( "<p class='two'>Number Two</p>");
});
</script>
<script>
$( "p.two" ).click(function() {
$( this ).replaceWith( "<p class='three'>Number Three</p>");
});
</script>
A: You have to delegate the p.two event since it w... | |
doc_23531264 | So in both cases, catgory_1 list and _category_2 list is server by content.php
mysite.com/category_1/post/
mysite.com/category_2/post/
So, I need to redirect the user to a different page depending on catgory_? list, but without affecting the post inside that category.
Resume :
if you visit mysite.com/category_1/post/ ... | |
doc_23531265 | For example:
redirecting www.example.com/index.html to www.example.com
<?xml version="1.0" encoding="UTF-8"?>
<configuration>
<system.webServer>
<modules runAllManagedModulesForAllRequests="true" />
<rewrite>
<rules>
<rule name="CanonicalHostNameRule" stopProcessing="true">
... | |
doc_23531266 | Here is my steps:
*
*Firstly I create a STFDF object called stfdf:
stfdf<-stConstruct(observation,space = list(values = 1:ncol(observation)),time = Node$Time,SpatialObj = loc,interval = T)
*Then I compute the empirical variogram with the spatial-temporal data stfdf:
var<-variogramST(values~1,data = stfdf,assumeRe... | |
doc_23531267 |
I want a UICollectionViewCell to expand to the whole screen. In this cell, the subviews are placed with Autolayout in IB.
I just want each subview to go to the new position. So I tried subview.frame = newSubview.frame in the animation block, but it doesn't work (because of Autolayout I think).
I thought to delete the... | |
doc_23531268 | <style>
@font-face {
font-family: 'robotoslab';
src: url("file://#{Rails.root.join('app', 'tmp', 'fonts', 'RobotoSlab-Thin.ttf')}");
}
</style>
And I am calling it like this
h5 {
text-transform: uppercase;
padding: 10px;
letter-spacing: 0.2px;
margin-top: 50px;
font-family: 'robotoslab'... | |
doc_23531269 |
*
*Click button, that's easy.
*Perform AJAX request and create a database table.
*Once the table is created, perform another series of AJAX requests and populate the table according to some parameters gotten from a series of select boxes.
*"Animate" the whole thing using a progress bar.
Surprisingly, everything... | |
doc_23531270 | The accepted answer got the select working with tokens and chunk size, but another problem manifested itself.
My table looks like this in cqlsh:
key | column1 | value
---------------+-----------------------+-------
85.166.4.140 | county_finnmark | 4
85.166.4.140 | county_id_2... | |
doc_23531271 | HttpParams httpParameters = new BasicHttpParams();
//Setup timeouts
HttpConnectionParams.setConnectionTimeout(httpParameters, 15000);
HttpConnectionParams.setSoTimeout(httpParameters, 15000);
UsernamePasswordCredentials creds = new UsernamePasswordCreden... | |
doc_23531272 | col1
200
300
400
200
500
700
0
0
60
0
0
I'm trying to create a new column that is determined based on the current row value but taking into account the next few row values also. So e.g. if (row_col1(i) > 60) & ((row_col1(i+1)+row_col1(i+2)+row_col1(i+3)) > 100), wri... | |
doc_23531273 |
I have created the first and the last Card views, but I am having trouble creating the cardviews in between, with all their features such as: the vertical divider, and the cut in the edges horizontal divider between the first and the second cardviews.
(**red Scissors and the blue circle are png's)
I am open to any oth... | |
doc_23531274 | Given the following options class:
public class Options
{
[Option('i', "int-option", DefaultValue = 10, HelpText = "Set the int")]
public int IntOption { get; set; }
[ParserState]
public IParserState LastParserState { get; set; }
[HelpOption]
public string GetUsage()
{
return HelpT... | |
doc_23531275 | Are there any commands that can help me achieve this? I need to parse these commit messages and use them in another place.
I have searched everywhere on the internet but I have found nothing useful.
Basically, I want to save this in a text file
Thank-you in advance...
| |
doc_23531276 | app.controller('MainCtrl',['$scope','Post','Pagination','Geolocation'
($scope, Post, Pagination, Geolocation) ->
$scope.posts = []
Geolocation.getLocation().then (location) ->
Pagination.paginate $scope, Post, 10, (postsRes) ->
$scope.posts.push posts for posts in postsRes
, params: {locat... | |
doc_23531277 | I've added a method which does the async call and handles the X-Ray based things, which works if I call it only once. However, if I call it again from the same thread, then X-Ray starts throwing .a.x.e.SegmentNotFoundException: Failed to begin subsegment named '30baae07-3a63-4036-807d-dcb0fdbac4eb': segment cannot be f... | |
doc_23531278 | I want to change the color of each button depending on the button pressed (to see the active filter)
This is my code:
<ButtonGroup variant="contained" aria-label="contained primary button group" >
<Button value={false} variant="contained" onClick={this.sortOnChange} color={this.state.relevanceColor}>Most Re... | |
doc_23531279 | <?php
//if($_SERVER['REQUEST_METHOD']=='POST'){
//$username = $_POST['username'];
$username = "Dave";
require_once('dbConnect.php');
$sql = "SELECT * FROM user WHERE username = '$username'";
$result = mysqli_query($con,$sql);
$check = mysqli_fetch_array($result);
if(isset($check)){
echo 'Logged in';
} else {
... | |
doc_23531280 | with respect
A: You will need to set up two Package Variables at design time to hold x and y.
In the General Tab of the Execute SQL component, change the result to SingleRow and ensure the query returns 1 row with the parameter details you require. Go to the Result Set Tab and set the two Package Variable (x, y... | |
doc_23531281 |
paypal_base (Properties: version 5.6.65.1, Runtime Version: v1.1.4322)
Questions:
Q1. What is URL of latest download?
Q2. I downloaded payflow_dotnet_setup_v4.33.zip and I'm reading "PayPal Payflow SDK for .NET Developer's Guide), BUT there is NO MENTION of any of the current calls I'm already using that look like th... | |
doc_23531282 | SHKItem *item = [SHKItem text:@"sample tweet"];
[SHKTwitter shareItem:item];
I try to attach UIImage with tweet using
SHKItem *item = [SHKItem image:[UIImage imageNamed:@"testImage.png"] title:@"posting test image"];
[SHKTwitter shareItem:item];
Although it posts successfully on twitter but instead of actual image ... | |
doc_23531283 |
*
*I am running tests that I know pass on everyone else's machine, including our build server
*Not using IIS Express is not an option, as then my build environment would be inconsistent with the team's. Furthermore, these tests were running just fine not a week ago, so this shouldn't be a problem.
*I have uninsta... | |
doc_23531284 | #compdef kubens
_arguments "1: :(- $(kubectl get namespaces -o=jsonpath='{range .items[*].metadata.name}{@}{"\n"}{end}'))"
This provides completion to the kubens command. However if user provides a certain installation argument, the program is linked with kns name, so I am trying to provide completion for both of thes... | |
doc_23531285 | 'Prompt for chart type
Dim chForm As ChartForm
Set chForm = New ChartForm
chForm.Show
However at runtime the code fails at the line where I try to set chForm as a new instance of ChartForm, giving Runtime Error 91 for a missing/undefined object. But I know that ChartForm exists, do I need to do something else to enabl... | |
doc_23531286 | My object model is stored in an .xcdatamodeld bundle, with versions 1.0 and 1.1 next to each other. Version 1.1 is set as the active version. Everything works fine when I use the default migration behavior and set NSInferMappingModelAutomaticallyOption to YES. My sqlite storage gets upgraded from the 1.0 version of the... | |
doc_23531287 | Google Chrome has a fantastic feature under it's Print options to Save to PDF. I can view my HTML file and save it as a paged PDF document.
I want to programatically, from my .Net app, use Google Chrome for it's PDF feature and automatically produce the PDF from the transformed XML?
How can I do this with my .Net code?... | |
doc_23531288 | Thanks for the help :)
A: Did you try looking in the documentation?
| |
doc_23531289 | I want to code this out
Array ( [0] => 1 [duration] => 1 [1] => Singapore [ai_Name] => Singapore )
{"duration":"1","ai_Name":"Singapore"}
but I am getting this instead
Array ( [0] => 1 [duration] => 1 [1] => Singapore [ai_Name] => Singapore )
{"0":"1","duration":"1","1":"Singapore","ai_Name":"Singapore"}
bel... | |
doc_23531290 | I used
How to write custom ExpandableListAdapter
for my ExpandableListView. As it stands at the moment i apply this t oa child convertView and it works fine on expand, but i cant figure out how it collapses.
Animation fadeAnimation = AnimationUtils.loadAnimation(getContext(), R.anim.slide_left_in);
convertView.start... | |
doc_23531291 | A user is tied to a company. A company has a License. A license has 2 expiration dates. expirationBasic and expirationExtended.
What I want:
For 50 routes I want to check if the license of the company of the logged in user has an expirationExtended > now.
For 50 routes I want to check if the license of the company of ... | |
doc_23531292 |
A: Add a helper column in the source data that indicates whether the row is for the last day in the month. Quick search for "excel last day of quarter" uncovers this possible formula: =DATE(YEAR(A2),CEILING(MONTH(A2),3)+1,0).
So if you put "Last day of Quarter" as a label in col X1, then the formula in X2 to return a... | |
doc_23531293 | λ> Data.List.cycle []
*** Exception: Prelude.cycle: empty list
I know that Haskells tries to use total functions (except for the fundamental functions head and tail) and I'm not entirely sure of why cycle is not one of them. In my mind, the cycle of the empty list is the empty list and I don't see problems with this.... | |
doc_23531294 | Now I want to debug a server that is launched from the client (VSCode), so I added in the debug flags for the spawned JVM process:
-Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=9999
Upon doing this suddenly, the server does not work any more, even though suspend = 0 and I confirmed the port is open and that... | |
doc_23531295 | $(document).ready(function() {
$("#myFormId").formValidate();
//other stuff
});
JQuery.fn.formValidate = function() {
var myForm = this;
$(myForm).validate({
//validation code is here
});
$("#exampleInputField").rules("add", {
required: true,
alphaNumeric: true,
min... | |
doc_23531296 | Is there way to delete all the version and the languages besides default language through Site core Rocks Query?
Thanks
A: You can delete the language item from the system/Languages and it will remove this language version from all the items automatically.
A: You can remove this language from the system and it will... | |
doc_23531297 | When i display a text of 10 characters it fits to it. But at times i will have to display more than 10 characters. So is there a way to shrink the the font size and make it to fit in my UILabel of length 100 ?
UILabel *la = [UILabel alloc]initWithFrame(5,10,100,14)];
A: Just use the adjustsFontSizeToFitWidth property... | |
doc_23531298 | for (i in 9:ncol(Site1)) {
print(qplot(Site1[,i],snowfree, data=Site1, geom_smooth(method = "loess", size = 1.5))
[i])
}
It results in a long list of
$<NA>
NULL
The function works outside of the loop, using simple x and y variables.
| |
doc_23531299 | How to hide the shortcut bar in iOS9
self.textfield.inputAssistantItem.leadingBarButtonGroups=@[];
self.textfield.inputAssistantItem.trailingBarButtonGroups=@[];
In my current viewController, there is only two textfield and in viewdidLoad the above code, thats it. But, don't know why its resulting in leaks, its a head... |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.